==> lms-1.1.2b.tar.gz: lms/modules/userbalance.php <==
<?php

/*
 * LMS version 1.1.2b
 *
 *  (C) Copyright 2001-2003 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: userbalance.php,v 1.16 2003/08/24 13:12:54 lukasz Exp $
 */

if(!$LMS->UserExists($_GET[id]))
	header("Location: ?m=userlist");

$username=$LMS->GetUserName($_GET[id]);
$id = $_GET[id];

$layout[pagetitle]="Rachunek uytkownika ".$username;

$SMARTY->assign("balancelist",$LMS->GetUserBalanceList($_GET[id]));
$SMARTY->assign("layout",$layout);
$SMARTY->assign("username",$username);
$SMARTY->assign("id",$id);
$SMARTY->display("userbalance.html");

/*
 * $Log: userbalance.php,v $
 * Revision 1.16  2003/08/24 13:12:54  lukasz
 * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
 *   redhat's :>
 *
 * Revision 1.15  2003/08/18 16:52:19  lukasz
 * - added CVS Log tags
 *
 */
?>

==> lms-1.1.5.tar.gz: lms/modules/userbalance.php <==
<?php

/*
 * LMS version 1.1.5 Amaonet
 *
 *  (C) Copyright 2001-2003 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: userbalance.php,v 1.19 2003/10/06 22:02:09 lukasz Exp $
 */

if(!$LMS->UserExists($_GET[id]))
	header("Location: ?m=userlist");

$username=$LMS->GetUserName($_GET[id]);
$id = $_GET[id];

$layout[pagetitle]='Rachunek uytkownika <A HREF="?m=userinfo&id='.$_GET[id].'">'.$username.'</A>';

$SMARTY->assign("balancelist",$LMS->GetUserBalanceList($_GET[id]));
$SMARTY->assign("layout",$layout);
$SMARTY->assign("username",$username);
$SMARTY->assign("id",$id);
$SMARTY->display("userbalance.html");

/*
 * $Log: userbalance.php,v $
 * Revision 1.19  2003/10/06 22:02:09  lukasz
 * - ju nie psuje
 *
 * Revision 1.18  2003/10/06 18:53:22  lexx
 * - odsyacz psu tytu strony
 *
 * Revision 1.17  2003/09/09 01:22:28  lukasz
 * - nowe finanse
 * - kosmetyka
 * - bugfixy
 * - i inne rzeczy o ktrych aktualnie nie pamitam
 *
 * Revision 1.16  2003/08/24 13:12:54  lukasz
 * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
 *   redhat's :>
 *
 * Revision 1.15  2003/08/18 16:52:19  lukasz
 * - added CVS Log tags
 *
 */
?>
